
    const sample = [
      {
        Name: 'Wii Sports',
        sales: 82.74,
        color: '#000000'
      },
      {
        Name: 'Super Mario Bros.',
        sales: 75.1,
        color: '#00a2ee'
      },
      {
        Name: 'Mario Kart Wii',
        sales: 35.82,
        color: '#fbcb39'
      },
      {
        Name: 'Wii Sport Resort',
        sales: 33,
        color: '#007bc8'
      },
      {
         Name: 'Go',
        sales: 65.6,
        color: '#65cedb'
      },
      {
        Name: 'Swift',
        sales: 65.1,
        color: '#ff6e52'
      },
      {
        Name: 'JavaScript',
        sales: 61.9,
        color: '#f9de3f'
      },
      {
        Name: 'C#',
        sales: 60.4,
        color: '#5d2f8e'
      },
      {
        Name: 'F#',
        sales: 59.6,
        color: '#008fc9'
      },
      {
        Name: 'Clojure',
        sales: 59.6,
        color: '#507dca'
      }
    ];

    const svg = d3.select('svg');
    const svgContainer = d3.select('#container');
    
    const margin = 80;
    const width = 1000 - 2 * margin;
    const height = 600 - 2 * margin;

    const chart = svg.append('g')
      .attr('transform', `translate(${margin}, ${margin})`);

    const xScale = d3.scaleBand()
      .range([0, width])
      .domain(sample.map((s) => s.Name))
      .padding(0.4)
    
    const yScale = d3.scaleLinear()
      .range([height, 0])
      .domain([0, 100]);

    // vertical grid lines
    // const makeXLines = () => d3.axisBottom()
    //   .scale(xScale)

    const makeYLines = () => d3.axisLeft()
      .scale(yScale)

    chart.append('g')
      .attr('transform', `translate(0, ${height})`)
      .call(d3.axisBottom(xScale));

    chart.append('g')
      .call(d3.axisLeft(yScale));

    // vertical grid lines
    // chart.append('g')
    //   .attr('class', 'grid')
    //   .attr('transform', `translate(0, ${height})`)
    //   .call(makeXLines()
    //     .tickSize(-height, 0, 0)
    //     .tickFormat('')
    //   )

    chart.append('g')
      .attr('class', 'grid')
      .call(makeYLines()
        .tickSize(-width, 0, 0)
        .tickFormat('')
      )

    const barGroups = chart.selectAll()
      .data(sample)
      .enter()
      .append('g')

    barGroups
      .append('rect')
      .attr('class', 'bar')
      .attr('x', (g) => xScale(g.Name))
      .attr('y', (g) => yScale(g.sales))
      .attr('height', (g) => height - yScale(g.sales))
      .attr('width', xScale.bandwidth())
      .on('mouseenter', function (actual, i) {
        d3.selectAll('.sales')
          .attr('opacity', 0)

        d3.select(this)
          .transition()
          .duration(300)
          .attr('opacity', 0.6)
          .attr('x', (a) => xScale(a.Name) - 5)
          .attr('width', xScale.bandwidth() + 10)

        const y = yScale(actual.sales)

        line = chart.append('line')
          .attr('id', 'limit')
          .attr('x1', 0)
          .attr('y1', y)
          .attr('x2', width)
          .attr('y2', y)

        barGroups.append('text')
          .attr('class', 'divergence')
          .attr('x', (a) => xScale(a.Name) + xScale.bandwidth() / 2)
          .attr('y', (a) => yScale(a.sales) + 30)
          .attr('fill', 'white')
          .attr('text-anchor', 'middle')
          .text((a, idx) => {
            const divergence = (a.sales - actual.sales).toFixed(1)
            
            let text = ''
            if (divergence > 0) text += '+'
            text += `${divergence}%`

            return idx !== i ? text : '';
          })

      })
      .on('mouseleave', function () {
        d3.selectAll('.sales')
          .attr('opacity', 1)

        d3.select(this)
          .transition()
          .duration(300)
          .attr('opacity', 1)
          .attr('x', (a) => xScale(a.Name))
          .attr('width', xScale.bandwidth())

        chart.selectAll('#limit').remove()
        chart.selectAll('.divergence').remove()
      })

    barGroups 
      .append('text')
      .attr('class', 'sales')
      .attr('x', (a) => xScale(a.Name) + xScale.bandwidth() / 2)
      .attr('y', (a) => yScale(a.sales) + 30)
      .attr('text-anchor', 'middle')
      .text((a) => `${a.sales}%`)
    
    svg
      .append('text')
      .attr('class', 'label')
      .attr('x', -(height / 2) - margin)
      .attr('y', margin / 2.4)
      .attr('transform', 'rotate(-90)')
      .attr('text-anchor', 'middle')
      .text('Global Sales (in millions)')

    svg.append('text')
      .attr('class', 'label')
      .attr('x', width / 2 + margin)
      .attr('y', height + margin * 1.7)
      .attr('text-anchor', 'middle')
      .text('Game Names')

    svg.append('text')
      .attr('class', 'title')
      .attr('x', width / 2 + margin)
      .attr('y', 40)
      .attr('text-anchor', 'middle')
      .text('Top sold Video Games Globally')

    